#
# spec file for package ghc-lca
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name lca
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3
Release:        8.1
Summary:        O(log n) persistent on-line lowest common ancestor calculation without preprocessing
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
%if %{with tests}
BuildRequires:  ghc-doctest-devel
%endif

%description
This package provides a reference implementation of my skew binary random
access algorithm for performing an /online/ lowest common ancestor search (and
online level ancestor search) in logarithmic time without preprocessing.
This improves the previous known asymptotic bound for both of these problems
from /O(h)/ to /O(log h)/, where /h/ is the height of the tree. Mostly
importantly this bound is completely independent of the width or overall size
of the tree, enabling you to calculate lowest common ancestors in a distributed
fashion with good locality.

While /offline/ algorithms exist for both of these algorithms that that provide
/O(1)/ query time, they all require at least /O(n)/ preprocessing, where /n/ is
the size of the entire tree, and so are less suitable for LCA search in areas
such as revision control where the tree is constantly updated, or distributed
computing where the tree may be too large to fit in any one computer's memory.

Slides are available from

<http://www.slideshare.net/ekmett/skewbinary-online-lowest-common-ancestor-search>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.3 revision 0 with cabal2obs.
